@@ -375,6 +375,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("fdf", &["application/vnd.fdf"]),
     ("fdt", &["application/fdt+xml"]),
     ("fe_launch", &["application/vnd.denovo.fcselayout-link"]),
+    ("feature", &["text/x-gherkin"]),
     ("fg5", &["application/vnd.fujitsu.oasysgp"]),
     ("fgd", &["application/x-director"]),
     ("fh", &["image/x-freehand"]),
@@ -423,6 +424,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("gca", &["application/x-gca-compressed"]),
     ("gdl", &["model/vnd.gdl"]),
     ("gdoc", &["application/vnd.google-apps.document"]),
+    ("gemini", &["text/gemini"]),
     ("generictest", &["application/xml"]),
     ("geo", &["application/vnd.dynageo"]),
     ("geojson", &["application/geo+json"]),
@@ -434,6 +436,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("gim", &["application/vnd.groove-identity-message"]),
     ("glb", &["model/gltf-binary"]),
     ("gltf", &["model/gltf+json"]),
+    ("gmi", &["text/gemini"]),
     ("gml", &["application/gml+xml"]),
     ("gmx", &["application/vnd.gmx"]),
     ("gnumeric", &["application/x-gnumeric"]),
@@ -458,7 +461,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("gxf", &["application/gxf"]),
     ("gxt", &["application/vnd.geonext"]),
     ("gz", &["application/gzip", "application/x-gzip"]),
-    ("h", &["text/x-c"]),
+    ("h", &["text/plain"]),
     ("h261", &["video/h261"]),
     ("h263", &["video/h263"]),
     ("h264", &["video/h264"]),
@@ -1289,6 +1292,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
     ("tpt", &["application/vnd.trid.tpt"]),
     ("tr", &["text/troff", "application/x-troff"]),
     ("tra", &["application/vnd.trueapp"]),
+    ("trig", &["application/trig"]),
     ("trm", &["application/x-msterminal"]),
     ("trx", &["application/xml"]),
     ("ts", &["video/mp2t", "video/vnd.dlna.mpeg-tts"]),
